VerticalFeedGroup class

This data class represents a story group in the VerticalFeed.

Constructors

VerticalFeedGroup({required String id, required String title, required int index, required bool seen, required String? iconUrl, required List<VerticalFeedItem> feedList, required bool pinned, required int type, required bool nudge, String? name})
VerticalFeedGroup.fromJson(Map<String, dynamic> json)
factory

Properties

feedList → List<VerticalFeedItem>
stories List of stories in the story group
final
hashCode → int
The hash code for this object.
no setterinherited
iconUrl → String?
iconUrl URL of the story group icon image
final
id → String
id ID of the story group
final
index → int
index Order index of the story group
final
name → String?
final
nudge → bool
final
pinned → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seen → bool
seen State of the story group that shows whether all of the stories are seen or not
final
title → String
title Title of the story group
final
type → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited