VerticalFeedItem class

This data class represents a story inside a story group.

Constructors

VerticalFeedItem({required String id, required String title, required int index, required bool seen, required int currentTime, String? previewUrl, String? actionUrl, List<STRProductItem>? actionProducts, String? name, List<VerticalFeedItemComponent?>? verticalFeedItemComponentList})
VerticalFeedItem.fromJson(Map<String, dynamic> json)
factory

Properties

actionProducts → List<STRProductItem>?
Related product content of interactive incase of click action
final
actionUrl → String?
URL which the user has just interacted with
final
currentTime → int
Time of the story that user watched
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
ID of the story
final
index → int
Index of the story among other stories of the story group
final
name → String?
Name of the story
final
previewUrl → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seen → bool
State of the story that shows whether the story is seen or not
final
title → String
Title of the story
final
verticalFeedItemComponentList → List<VerticalFeedItemComponent?>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited