VerticalFeedItemComponent class

This parent class represents the interactive components which users are interacted with.

Implementers

Constructors

VerticalFeedItemComponent(String type, String id, String? customPayload)
VerticalFeedItemComponent.fromJson(Map<String, dynamic> json)
factory

Properties

customPayload → String?
custom payload for the interactive component if exists
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
id of the interactive component
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
type Type of the interactive component
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited