VerticalFeedItemPromocodeComponent class

This data class represents the Promocode component.

Implemented types

Constructors

VerticalFeedItemPromocodeComponent({required String type, required String id, required String? customPayload, required String text})
VerticalFeedItemPromocodeComponent.fromJson(Map<String, dynamic> json)
factory

Properties

customPayload → String?
custom payload for the interactive component if exists
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
id of the interactive component
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
copied value from user in Promocode component
final
type → String
type Type of the interactive component
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited