VerticalFeedItemQuizComponent class

This data class represents the Quiz component.

Implemented types

Constructors

VerticalFeedItemQuizComponent({required String type, required String id, required String? customPayload, int? rightAnswerIndex, required String title, required List<String> options, required int selectedOptionIndex})
VerticalFeedItemQuizComponent.fromJson(Map<String, dynamic> json)
factory

Properties

customPayload → String?
custom payload for the interactive component if exists
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
id of the interactive component
final
options → List<String>
options List of options in the quiz
final
rightAnswerIndex → int?
rightAnswerIndex Index of the right answer if exists
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedOptionIndex → int
selectedOptionIndex Option index that the user selected
final
title → String
title Title of the quiz if exists
final
type → String
type Type of the interactive component
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited