VerticalFeedItemRatingComponent class

This data class represents the Rating component.

Implemented types

Constructors

VerticalFeedItemRatingComponent({required String type, required String id, required String? customPayload, required int rating, required String emojiCode})
VerticalFeedItemRatingComponent.fromJson(Map<String, dynamic> json)
factory

Properties

customPayload → String?
custom payload for the interactive component if exists
final
emojiCode → String
emojiCode Emoji code as the thumb emoji
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
id of the interactive component
final
rating → int
rating Rating value which user rated in the component
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
type Type of the interactive component
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited