VerticalFeedParam class

This class is used to customize the VerticalFeed

Constructors

VerticalFeedParam()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isProductCartEnabled ↔ bool?
This attribute allows you to set availability of cart
getter/setter pair
isProductFallbackEnabled ↔ bool?
This attribute allows you to enable hydration from feed data from backend
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storylyCustomParameters ↔ String?
Storyly SDK allows you to send a string parameter in the initialization process. This field is used for this analytical pruposes.
getter/setter pair
storylyFacebookAppID ↔ String?
This attibute allows you to set Facebook app id to be used in Instagram share to storiess.
getter/setter pair
storylyId ↔ String?
This attribute required for your app's correct initialization.
getter/setter pair
storylyLayoutDirection ↔ String?
This attribute allows you to change the layout direction the vertical feed view.
getter/setter pair
storylyLocale ↔ String?
This function allows you to set localization for the storyly view. Sample convention is en-GB
getter/setter pair
storylySegments ↔ List<String>?
This attribute takes a list of string which will be used in process of segmentation to show sepecific story groups to the users.
getter/setter pair
storylyShareUrl ↔ String?
This attibute allows you to change share URL of stories.
getter/setter pair
storylyTestMode ↔ bool?
This attribute defines whether it is a test device or not. If true, test groups are sent from the server.
getter/setter pair
storylyUserProperty ↔ Map<String, String>?
This attribue takes a map which will be used to replace user data set in dashboard to show user specific content.
getter/setter pair
storyProductFeed ↔ Map<String, List<STRProductItem>>?
This attribute allows you to set product feed
getter/setter pair
verticalFeedGroupIconBackgroundColor ↔ Color?
This attribute allows you to change the background color of the vertical feed group icon which is shown to the user as skeleton view till the stories are loaded.
getter/setter pair
verticalFeedGroupIconCornerRadius ↔ int?
This attribute allows you to changes the corner radius of vertical feed group icon.
getter/setter pair
verticalFeedGroupIconHeight ↔ int?
This attribute allows you to changes the height of vertical feed group icon.
getter/setter pair
verticalFeedGroupImpressionIcon ↔ String?
This attribute allows you to set minimum impression count to show impression icon.
getter/setter pair
verticalFeedGroupLikeIcon ↔ String?
This attribute allows you to set minimum like count to show like icon.
getter/setter pair
verticalFeedGroupListHorizontalEdgePadding ↔ int?
This attribute changes edge padding value of the first and last vertical feed groups for orientation horizontal
getter/setter pair
verticalFeedGroupListHorizontalPaddingBetweenItems ↔ int?
This attribute changes horizontal padding value between vertical feed groups
getter/setter pair
verticalFeedGroupListSections ↔ int?
This attribute changes based on orientation horizontal orientation row count or vertical orientation column count of vertical feed group list
getter/setter pair
verticalFeedGroupListVerticalEdgePadding ↔ int?
This attribute changes edge padding value of the first and last vertical feed groups for orientation vertical
getter/setter pair
verticalFeedGroupListVerticalPaddingBetweenItems ↔ int?
This attribute changes vertical padding value between vertical feed groups
getter/setter pair
verticalFeedGroupMinImpressionCountToShowIcon ↔ int?
This attribute allows you to set minimum impression count to show impression icon
getter/setter pair
verticalFeedGroupMinLikeCountToShowIcon ↔ int?
This attribute allows you to set minimum like count to show like icon
getter/setter pair
verticalFeedGroupOrder ↔ String?
This attribute allows you to change the order of the vertical feed group.
getter/setter pair
verticalFeedGroupTextColor ↔ Color?
This attribute allows you to change the text color of the vertical feed group.
getter/setter pair
verticalFeedGroupTextIsVisible ↔ bool?
This attribute allows you to changes the visibility of vertical feed group text.
getter/setter pair
verticalFeedGroupTextSize ↔ int?
This attribute allows you to change text size vertical feed group text.
getter/setter pair
verticalFeedGroupTextTypeface ↔ String?
This attribute allows you to change font of vertical feed group text.
getter/setter pair
verticalFeedInteractiveTextTypeface ↔ String?
This attribute allows you to change the interactive component font of the vertical feed view.
getter/setter pair
verticalFeedItemCloseButtonIsVisible ↔ bool?
This attribute allows you to changes the visibility of vertical feed header close button.
getter/setter pair
verticalFeedItemCloseIcon ↔ String?
This attribute allows you to use custom icon for header close button.
getter/setter pair
verticalFeedItemLikeButtonIsVisible ↔ bool?
This attribute allows you to changes the visibility of vertical feed like button.
getter/setter pair
verticalFeedItemLikeIcon ↔ String?
This attribute allows you to use custom icon for like button.
getter/setter pair
verticalFeedItemProgressBarColor ↔ List<Color>?
This attribute allows you to change the progress bar colors of the vertical feed view.
getter/setter pair
verticalFeedItemProgressBarIsVisible ↔ bool?
This attribute allows you to changes the visibility of vertical feed progress bar.
getter/setter pair
verticalFeedItemShareButtonIsVisible ↔ bool?
This attribute allows you to changes the visibility of vertical feed share button.
getter/setter pair
verticalFeedItemShareIcon ↔ String?
This attribute allows you to use custom icon for header share button.
getter/setter pair
verticalFeedItemTextTypeface ↔ String?
This attribute allows you to change the header text font of the vertical feed view.
getter/setter pair
verticalFeedItemTitleIsVisible ↔ bool?
This attribute allows you to changes the visibility of story header text.
getter/setter pair
verticalFeedTypeIndicatorIsVisible ↔ bool?
This attribute allows you to set vertical feed type indicator visibility.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited