VerticalFeedPresenterController class

Constructors

VerticalFeedPresenterController(int _viewId, MethodChannel _methodChannel)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

approveCartChange(String responseId, Map<String, dynamic>? cart) → Future<void>
approveWishlistChange(String responseId, Map<String, dynamic>? item) → Future<void>
getViewId() → int
hydrateProducts(List<STRProductItem> products) → Future<void>
This function allows you to hydrate products.
hydrateWishlist(List<STRProductItem> products) → Future<void>
This function allows you to hydrate products.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → Future<void>
This function allows you to pause the presenter
play() → Future<void>
This function allows you to play the presenter
refresh() → Future<void>
This function allows you to refetch the data from network by default you do not need to use this function.
rejectCartChange(String responseId, String failMessage) → Future<void>
rejectWishlistChange(String responseId, String failMessage) → Future<void>
toString() → String
A string representation of this object.
inherited
updateCart(Map cart) → Future<void>
This function allows you to update your cart.

Operators

operator ==(Object other) → bool
The equality operator.
inherited