VerticalFeed class

Vertical Feed UI Widget

Inheritance

Constructors

VerticalFeed({Key? key, VerticalFeedCreatedCallback? onVerticalFeedCreated, VerticalFeedParam? androidParam, VerticalFeedParam? iosParam, VerticalFeedLoadedCallback? verticalFeedLoaded, VerticalFeedLoadFailedCallback? verticalFeedLoadFailed, VerticalFeedActionClickedCallback? verticalFeedActionClicked, VoidCallback? verticalFeedShown, VerticalFeedPresentFailed? verticalFeedShowFailed, VoidCallback? verticalFeedDismissed, VerticalFeedEventCallback? verticalFeedEvent, VerticalFeedOnProductHydrationCallback? verticalFeedOnProductHydration, VerticalFeedProductEventCallback? verticalFeedProductEvent, VerticalFeedOnProductCartUpdatedCallback? verticalFeedOnProductCartUpdated, VerticalFeedOnWishlistUpdatedCallback? verticalFeedOnWishlistUpdated, VerticalFeedUserInteractedCallback? verticalFeedUserInteracted})
const

Properties

androidParam → VerticalFeedParam?
Android specific VerticalFeedParam
final
hashCode → int
The hash code for this object.
no setterinherited
iosParam → VerticalFeedParam?
iOS specific VerticalFeedParam
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onVerticalFeedCreated → VerticalFeedCreatedCallback?
This callback function allows you to access VerticalFeedController
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalFeedActionClicked → VerticalFeedActionClickedCallback?
This callback function will notify your application in case of Swipe Up or CTA Button action.
final
verticalFeedDismissed → VoidCallback?
This callback function will let you know that user dismissed the current story while watching it.
final
verticalFeedEvent → VerticalFeedEventCallback?
This callback function will notify you about all Storyly events and let you to send these events to specific data platforms
final
verticalFeedLoaded → VerticalFeedLoadedCallback?
This callback function will let you know that Storyly has completed its network operations and story group list has just shown to the user.
final
verticalFeedLoadFailed → VerticalFeedLoadFailedCallback?
This callback function will let you know that Storyly has completed its network operations and had a problem while fetching your stories.
final
verticalFeedOnProductCartUpdated → VerticalFeedOnProductCartUpdatedCallback?
This callback function will notify you about updates the cart in a VerticalFeed component
final
verticalFeedOnProductHydration → VerticalFeedOnProductHydrationCallback?
This callback function will notify your application in case product hydration
final
verticalFeedOnWishlistUpdated → VerticalFeedOnWishlistUpdatedCallback?
This callback function will notify you about updates the wishlist in a VerticalFeedBar component
final
verticalFeedProductEvent → VerticalFeedLoadFailedCallback?
This callback function will notify your application in case product event occurs
final
verticalFeedShowFailed → VerticalFeedLoadFailedCallback?
This callback function will let you know that vertical feed present failed
final
verticalFeedShown → VoidCallback?
This callback function will let you know that stories are started to be presented to the users.
final
verticalFeedUserInteracted → VerticalFeedUserInteractedCallback?
This callback function will allow you to get reactions of users from specific interactive components.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<VerticalFeed>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited